@@ -56,6 +56,10 @@ pub struct Shared {
 /// All settings which are used by the client
 #[derive(PartialEq, Clone, Debug, Deserialize, Serialize)]
 pub struct Client {
+    /// If set to true, all tasks will be restart in place, instead of creating a new task.
+    /// False is the default, as you'll lose the logs of the previously failed tasks when
+    /// restarting tasks in place.
+    pub restart_in_place: bool,
     /// Whether the client should read the logs directly from disk or whether it should
     /// request the data from the daemon via socket.
     pub read_local_logs: bool,
@@ -65,10 +69,13 @@ pub struct Client {
     /// or shown in their short form.
     pub show_expanded_aliases: bool,
     /// Whether the client should use dark shades instead of regular colors.
-    #[serde(default = "default_dark_mode")]
     pub dark_mode: bool,
     /// The max amount of lines each task get's in the `pueue status` view.
     pub max_status_lines: Option<usize>,
+    /// The format that will be used to display time formats in `pueue status`.
+    pub status_time_format: String,
+    /// The format that will be used to display datetime formats in `pueue status`.
+    pub status_datetime_format: String,
 }
 
 /// All settings which are used by the daemon
@@ -83,7 +90,6 @@ pub struct Daemon {
     /// The callback that's called whenever a task finishes.
     pub callback: Option<String>,
     /// The amount of log lines from stdout/stderr that are passed to the callback command.
-    #[serde(default = "default_callback_log_lines")]
     pub callback_log_lines: usize,
     /// This shouldn't be manipulated manually if the daemon is running.
     /// This represents all known groups and their amount of parallel tasks.
@@ -186,6 +192,7 @@ impl Settings {
             .unwrap();
 
         // Client specific config
+        config.set_default("client.restart_in_place", true).unwrap();
         config.set_default("client.read_local_logs", true).unwrap();
         config
             .set_default("client.show_expanded_aliases", false)
@@ -197,6 +204,9 @@ impl Settings {
         config
             .set_default("client.max_status_lines", None::<i64>)
             .unwrap();
+        config
+            .set_default("client.newline_between_date_and_time", false)
+            .unwrap();
 
         // Daemon specific config
         config
@@ -301,15 +311,3 @@ fn parse_config(
     // Try to can deserialize the entire configuration
     Ok(config.try_into()?)
 }
-
-/// The default value for the `dark_mode` client settings.
-/// Needed to keep backward compatibility between v0.11 and v0.12
-fn default_dark_mode() -> bool {
-    false
-}
-
-/// The default value for the `dark_mode` client settings.
-/// Needed to keep backward compatibility between v0.11 and v0.12
-fn default_callback_log_lines() -> usize {
-    10
-}
